==> App-MtAws-1.103_4.tar.gz: App-MtAws-1.103_4/lib/App/MtAws/QueueJob/DownloadInventory.pm <==
# mt-aws-glacier - Amazon Glacier sync client
# Copyright (C) 2012-2013  Victor Efimov
# http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
# License: GPLv3
#
# This file is part of "mt-aws-glacier"
#
#    mt-aws-glacier is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    mt-aws-glacier is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

package App::MtAws::QueueJob::DownloadInventory;

our $VERSION = '1.103_4';

use strict;
use warnings;
use Carp;

use App::MtAws::QueueJobResult;
use base 'App::MtAws::QueueJob';

sub init
{
	my ($self) = @_;
	$self->{job_id} || confess;
	$self->enter('download');
}

sub on_download
{
	my ($self) = @_;
	return state "wait", task "inventory_download_job", { job_id => $self->{job_id} } => sub {
		my ($args, $attachment) = @_;
		$self->{inventory_raw_ref} = $attachment || confess "no attachment"; # we don't expect undef/FALSE here. only scalar ref
		$self->{inventory_type} = $args->{inventory_type} || confess "no inventory type";
		state("done")
	}
}

1;

==> App-MtAws-1.110.tar.gz: App-MtAws-1.110/lib/App/MtAws/QueueJob/DownloadInventory.pm <==
# mt-aws-glacier - Amazon Glacier sync client
# Copyright (C) 2012-2013  Victor Efimov
# http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
# License: GPLv3
#
# This file is part of "mt-aws-glacier"
#
#    mt-aws-glacier is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    mt-aws-glacier is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

package App::MtAws::QueueJob::DownloadInventory;

our $VERSION = '1.110';

use strict;
use warnings;
use Carp;

use App::MtAws::QueueJobResult;
use base 'App::MtAws::QueueJob';

sub init
{
	my ($self) = @_;
	$self->{job_id} || confess;
	$self->enter('download');
}

sub on_download
{
	my ($self) = @_;
	return state "wait", task "inventory_download_job", { job_id => $self->{job_id} } => sub {
		my ($args, $attachment) = @_;
		$self->{inventory_raw_ref} = $attachment || confess "no attachment"; # we don't expect undef/FALSE here. only scalar ref
		$self->{inventory_type} = $args->{inventory_type} || confess "no inventory type";
		state("done")
	}
}

1;
